# waterch-tasker
![License](https://img.shields.io/github/license/chenrz925/waterch-tasker?style=flat-square)
![Last Commit](https://img.shields.io/github/last-commit/chenrz925/waterch-tasker?style=flat-square)
![PyPI](https://img.shields.io/pypi/v/waterch-tasker?style=flat-square)
![GitHub Workflow Status](https://img.shields.io/github/workflow/status/chenrz925/waterch-tasker/CI?style=flat-square)

A scalable and extendable experiment task scheduler framework.
